@@ -1,10 +1,7 @@
 """
 TIM Python Client.
 """
-from .tim import *
+from .client import *
 from . import _version
 
-__version__ = _version.get_versions()['version']
-
-from . import _version
-__version__ = _version.get_versions()['version']
+__version__ = _version.get_versions()['version']
\ No newline at end of file
