@@ -6,7 +6,6 @@ from .authentication import verify_credentials
 
 T = TypeVar('T')
 
-
 def execute_request(
     credentials: Credentials,
     method: str,
@@ -18,12 +17,12 @@ def execute_request(
   verified_credentials = verify_credentials(credentials)
   headers = {
       "Authorization": f"Bearer {verified_credentials.token}",
-      "X-Tim-Client": verified_credentials.clientName,
+      "X-Tim-Client": verified_credentials.client_name,
   }
 
   upload_file = lambda: requests.request(
       method=method,
-      url=f"{verified_credentials.endpoint}{path}",
+      url=f"{verified_credentials.server}{path}",
       headers=headers,
       files={
           "configuration": json.dumps(body),
@@ -33,7 +32,7 @@ def execute_request(
 
   handle_request = lambda: requests.request(
       method=method,
-      url=f"{verified_credentials.endpoint}{path}",
+      url=f"{verified_credentials.server}{path}",
       json=body,
       params=params,
       headers=headers,
@@ -50,4 +49,4 @@ def execute_request(
   if response.headers.get('content-type') == 'application/json':
     return response.json()
 
-  return response.text
+  return response.text
\ No newline at end of file
