@@ -1,26 +1,25 @@
 from typing import Optional
-from tim.endpoint import endpoint as default_endpoint
-
+from .server import server as default_server
 
 class Credentials:
   __email: Optional[str] = None
   __password: Optional[str] = None
   __token: Optional[str] = None
   __token_expiration: str = ""
-  __endpoint: Optional[str] = None
-  __clientName: Optional[str] = None
+  __server: Optional[str] = None
+  __client_name: Optional[str] = None
 
   def __init__(
       self,
       email: str,
       password: str,
-      endpoint: str = default_endpoint,
-      clientName: str = "Python Client",
+      server: str = default_server,
+      client_name: str = "Python Client",
   ):
     self.__email = email
     self.__password = password
-    self.__endpoint = endpoint
-    self.__clientName = clientName
+    self.__server = server
+    self.__client_name = client_name
 
   @property
   def email(self):
@@ -35,12 +34,12 @@ class Credentials:
     return self.__password
 
   @property
-  def endpoint(self):
-    return self.__endpoint
+  def server(self):
+    return self.__server
 
   @property
-  def clientName(self):
-    return self.__clientName
+  def client_name(self):
+    return self.__client_name
 
   @property
   def token_expiration(self):
@@ -52,4 +51,4 @@ class Credentials:
 
   @token_expiration.setter
   def token_expiration(self, token_expiration: str):
-    self.__token_expiration = token_expiration
+    self.__token_expiration = token_expiration
\ No newline at end of file
